package com.example.siamobile

import android.annotation.SuppressLint
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.text.BasicTextField
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import com.example.siamobile.ui.theme.SIAMobileTheme




class Mhs202210715240 : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        val mahasiswaName = intent.getStringExtra("mahasiswaName") ?: "NPM: 202210715088 Nama:Risky Pujianto"
        setContent {
            SIAMobileTheme {
                DetailMahasiswaScreen(mahasiswaName)
            }
        }
    }
}

@SuppressLint("MutableCollectionMutableState")
@Composable
fun DetailMahasiswaScreen(mahasiswaName: String) {
    val context = LocalContext.current

    // Data mata pelajaran per semester
    val semesterSubjects = mapOf(
        "Semester 1" to listOf("Matematika Diskrit", "Dasar Pemrograman", "Logika Informatika"),
        "Semester 2" to listOf("Struktur Data", "Pemrograman Berbasis Objek", "Statistika"),
        "Semester 3" to listOf("Sistem Operasi", "Jaringan Komputer", "Analisis dan Desain Sistem"),
        "Semester 4" to listOf("Pemrograman Mobile", "Keamanan Informasi", "Manajemen Proyek TI"),
        "Semester 5" to listOf("Kecerdasan Buatan", "Pembelajaran Mesin", "Manajemen Sekuriti")
    )

    // Menggunakan map untuk menyimpan nilai untuk setiap mata pelajaran
    var nilaiList by remember { mutableStateOf(mutableMapOf<String, String>()) }

    val scrollState = rememberScrollState() // Scroll state

    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        verticalArrangement = Arrangement.SpaceBetween
    ) {
        Column(
            modifier = Modifier
                .weight(1f) // Berikan bobot agar bisa menggulir
                .verticalScroll(scrollState) // Tambahkan scrolling
        ) {
            Text(
                text = "KHS Mahasiswa",
                style = MaterialTheme.typography.headlineMedium,
                fontWeight = FontWeight.Bold
            )
            Spacer(modifier = Modifier.height(8.dp))
            Text(
                text = mahasiswaName,
                style = MaterialTheme.typography.bodyLarge,
                fontWeight = FontWeight.Medium
            )
            Spacer(modifier = Modifier.height(16.dp))

            // Menampilkan daftar mata pelajaran per semester
            for ((semester, subjects) in semesterSubjects) {
                Text(
                    text = semester,
                    style = MaterialTheme.typography.bodyLarge,
                    fontWeight = FontWeight.Bold
                )
                Spacer(modifier = Modifier.height(8.dp))

                for (mataPelajaran in subjects) {
                    Row(
                        modifier = Modifier.fillMaxWidth(),
                        horizontalArrangement = Arrangement.SpaceBetween,
                        verticalAlignment = Alignment.CenterVertically
                    ) {
                        Text(
                            text = mataPelajaran,
                            style = MaterialTheme.typography.bodyMedium,
                            modifier = Modifier.weight(1f)
                        )

                        // TextField untuk input nilai
                        BasicTextField(
                            value = nilaiList[mataPelajaran] ?: "",
                            onValueChange = { newValue ->
                                nilaiList = nilaiList.toMutableMap().apply {
                                    this[mataPelajaran] = newValue
                                }
                            },
                            modifier = Modifier
                                .padding(start = 8.dp)
                                .width(80.dp)
                                .border(1.dp, MaterialTheme.colorScheme.primary)
                                .padding(8.dp),
                            textStyle = MaterialTheme.typography.bodyMedium
                        )
                    }
                    Spacer(modifier = Modifier.height(8.dp))
                }
                Spacer(modifier = Modifier.height(16.dp))
            }
        }

        Button(
            onClick = { (context as? ComponentActivity)?.finish() },
            modifier = Modifier.align(Alignment.CenterHorizontally)
        ) {
            Text(text = "Kembali")
        }
    }
}
